"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getPluginRegistryV1AccountDataSerializer = exports.getRegistryRecordSerializer = void 0;
const serializers_1 = require("@metaplex-foundation/umi/serializers");
const generated_1 = require("../generated");
function getRegistryRecordSerializer() {
    return {
        description: 'RegistryRecordWithUnknown',
        fixedSize: null,
        maxSize: null,
        serialize: () => {
            throw new Error('Operation not supported.');
        },
        deserialize: (buffer, offset = 0) => {
            let [pluginType, pluginTypeOffset, isUnknown] = [
                generated_1.PluginType.Attributes,
                offset + 1,
                true,
            ];
            try {
                [pluginType, pluginTypeOffset] = (0, generated_1.getPluginTypeSerializer)().deserialize(buffer, offset);
                isUnknown = false;
            }
            catch (e) {
                // Do nothing, unknown plugin type
            }
            const [authority, authorityOffset] = (0, generated_1.getPluginAuthoritySerializer)().deserialize(buffer, pluginTypeOffset);
            const [pluginOffset, pluginOffsetOffset] = (0, serializers_1.u64)().deserialize(buffer, authorityOffset);
            return [
                {
                    pluginType,
                    authority,
                    offset: pluginOffset,
                    isUnknown,
                },
                pluginOffsetOffset,
            ];
        },
    };
}
exports.getRegistryRecordSerializer = getRegistryRecordSerializer;
function getPluginRegistryV1AccountDataSerializer() {
    return {
        description: 'PluginRegistryV1AccountData',
        fixedSize: null,
        maxSize: null,
        serialize: () => {
            throw new Error('Operation not supported.');
        },
        deserialize: (buffer, offset = 0) => {
            const [key, keyOffset] = (0, generated_1.getKeySerializer)().deserialize(buffer, offset);
            if (key !== generated_1.Key.PluginRegistryV1) {
                throw new Error(`Expected a PluginRegistryV1 account, got key: ${key}`);
            }
            const [registry, registryOffset] = (0, serializers_1.array)(getRegistryRecordSerializer()).deserialize(buffer, keyOffset);
            // TODO deserialize externalPlugins once they are defined, purposefully ignore them now
            return [
                {
                    key,
                    registry: registry.filter((record) => !record.isUnknown),
                    externalPlugins: [],
                },
                registryOffset,
            ];
        },
    };
}
exports.getPluginRegistryV1AccountDataSerializer = getPluginRegistryV1AccountDataSerializer;
//# sourceMappingURL=pluginRegistryV1Data.js.map